Examples
========================================================================================

Some examples of how to use the TAPE package are provided in these notebooks.

.. toctree::

    Use Lomb–Scargle Periodograms for SDSS Stripe 82 RR Lyrae <examples/rrlyr-period>
